<?php
class GoogleSpreadSheetService
{
    function intializeGoogleClient($credentialsPath)
    {
        $client = new Google_Client();
        $client->setApplicationName('Google Sheets and PHP Integration');
        $client->setScopes([Google_Service_Sheets::SPREADSHEETS]);
        $client->setAuthConfig($credentialsPath);
        $client->setAccessType('offline');
        $client->setPrompt('select_account consent');
        $client->setState('abc');
        $client->setRedirectUri('http://localhost/phppot/php/google-sheet-php/index.php');
        return $client;
    }

    function storeOauthToken($accessToken)
    {

        $_SESSION['access_token'] = $accessToken;
    }

    function getOauthTokenFromGoogle($client)
    {
        // Handle OAuth 2.0 server response
        if (isset($_GET['code']) && !isset($_SESSION['access_token'])) {
            $accessToken = $client->fetchAccessTokenWithAuthCode($_GET['code']);
            $client->setAccessToken($accessToken);

            $this->storeOauthToken($accessToken);
            // Redirect to remove the code from URL
            header('Location: ' . filter_var($client->getRedirectUri(), FILTER_SANITIZE_URL));
            exit();
        }
    }
    function getOauthToken()
    {
        if (!empty($_SESSION['access_token'])) {

            $accessToken = $_SESSION['access_token'];
            return $accessToken;
        }
    }

    function refreshToken($client, $accessToken)
    {
        $client->setAccessToken($accessToken);

        // Refresh the token if it's expired
        if ($client->isAccessTokenExpired()) {
            if ($client->getRefreshToken()) {
                $client->fetchAccessTokenWithRefreshToken($client->getRefreshToken());
            } else {
                $authUrl = $client->createAuthUrl();
                header('Location: ' . filter_var($authUrl, FILTER_SANITIZE_URL));
                exit();
            }
        }
    }

    function createSpreadSheet($client)
    {
        $spreadsheet = new Google_Service_Sheets_Spreadsheet([
            'properties' => ['title' => 'New spreedsheet'] // Give the title for the spreadsheet
        ]);
        $service = new Google_Service_Sheets($client);
        try {
            $spreadsheet = $service->spreadsheets->create($spreadsheet, ['fields' => 'spreadsheetId']);
            $spreadsheetId = $spreadsheet->spreadsheetId;
            return $spreadsheetId;
            // Get the spreadsheet ID of new file created
        } catch (Exception $e) {
            echo 'An error occurred while creating the spreadsheet: ' . $e->getMessage();
        }
    }

    function insertHeading($client, $spreadsheetId, $values)
    {
        $service = new Google_Service_Sheets($client);
        $range = 'Sheet1'; // Google spreadsheet range
        // Build body with record set
        $body = new Google_Service_Sheets_ValueRange(['values' => $values]);
        $params = ['valueInputOption' => 'RAW'];

        $result = "";
        try {
            //Append data with respect to the spreadsheet id
            $result = $service->spreadsheets_values->append($spreadsheetId, $range, $body, $params);
        } catch (Exception $e) {
            echo 'An error occurred: ' . $e->getMessage();
        }
        return $result;
    }
}
