<?php
session_start();

require_once __DIR__ . '/init-google-client.php';

if (!empty($accessToken)) {
    // Check token expiry and refresh if expired
    $googleSpreadSheetService->refreshToken($client, $accessToken);
} else {
    $authUrl = $client->createAuthUrl();
    // Redirect to auth URL to get enduser concent to allow the App to access the Google sheet
    header('Location: ' . filter_var($authUrl, FILTER_SANITIZE_URL));
    exit();
}
?>
<html>

<head>
    <link href="css/form.css" rel="stylesheet" type="text/css" />
    <link href="css/style.css" rel="stylesheet" type="text/css" />
    <title>Inser data from PHP Form to Google Sheet</title>
    <style>
        .phppot-container {
            margin-top: 100px;
        }

        .tile-container {
            margin: 0 auto;
        }
    </style>
</head>

<body>
    <div class="phppot-container">
        <?php
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $name = $_POST['name'];
            $email = $_POST['email'];

            $range = 'Sheet1'; // Adjust range accordingly
            $values = [[$name, $email]]; // Data to be written

            $body = new Google_Service_Sheets_ValueRange(['values' => $values]);
            $params = ['valueInputOption' => 'RAW'];
            $service = new Google_Service_Sheets($client);

            try {
                require_once __DIR__ . '/SpreadsheetModel.php';
                $spreadsheetModel = new SpreedsheetModel();
                $spreadsheetId = $spreadsheetModel->getSpreadSheetId();

                $result = $service->spreadsheets_values->append($spreadsheetId, $range, $body, $params);
                $output = "<div class='phppot-message success'>Data inserted into the Google sheet. ";
                $output .= "<a href='https://docs.google.com/spreadsheets/d/" . $spreadsheetId . "'
                 target='_blank'>View spreadsheet</a>.";
                $output .= "</div>";
            } catch (Exception $e) {
                $output = '<div class="phppot-message error">An error occurred: ' . $e->getMessage() . "</div>";
            }
            echo $output;
        ?>
        <?php
        } else {
        ?>
            <div class="tile-container">
                <form name="frmSheetData" method="post">
                    <div class="row">
                        <label for="name">Name:</label>
                        <input type="text" name="name" class="full-width" required>
                    </div>
                    <div class="row">
                        <label for="email">Email:</label>
                        <input type="email" name="email" class="full-width" required>
                    </div>
                    <div class="row">
                        <input type="submit" value="Submit" class="full-width">
                    </div>
                </form>
            </div>
        <?php
        }
        ?>
    </div>
</body>

</html>